@@ -62,11 +62,16 @@ def break_out_individuals_cpl(
   aa3_df['row_type'] = 'aa3'
   aa4_df['row_type'] = 'aa4'
 
-  # Concatenate the three dataframes into a single dataframe
+  # concatenate the three dataframes into a single dataframe
   combined_df = pandas.concat([claimant_df, partner_df, landlord_df, aa2_df, aa3_df, aa4_df], axis=0, ignore_index=True) \
     .dropna(subset=['forename', 'surname', 'address_1', 'postcode'])
+  
+  # clean any rogue excel encoding in addresses
+  for key in ['address_1', 'address_2', 'address_3', 'postcode']:
+    if key in combined_df.columns:
+      combined_df[key] = combined_df[key].fillna('').str.replace('_x000D_', ', ')
 
-  # write stats
+  # write stats to stdout
   for key in ['claimant', 'partner', 'landlord', 'aa2', 'aa3', 'aa4']:
     subset = combined_df[combined_df['row_type'] == key]
     print(f"{key}: {len(subset)}")
